=======================
Usage / Getting started
=======================

To use pymoskito you can either follow the shortcut which is provided in the
first section, or take a little tour and learn how to compose a complete system
on your own. Since time is money you may begin by taking the shortcut and play
around a little to get used to it but if you have greater things in mind sooner
or later you will have to take the complete lesson to get to know all features
this toolbox has to offer.


A Shortcut
----------

The easiest way to use PyMoskito for your project is to copy one of the examples
and modify it to fit your needs. Lets say you copied the
:doc:`/examples/ballbeam` example and renamed it to `my_system`. You can now
start the example by entering::

    $ python -m my_system


or from inside the directory by calling::

    $ python .

or::

    $ python __main__.py

. All of these commands will do the same thing and start your example.

To use PyMoskito in a project::

    import pymoskito


The complete Path
-----------------

TODO
